Module: Mml::Base::Content::Lambda
- Included in:
- V2::Lambda, V3::Lambda, V4::Lambda
- Defined in:
- lib/mml/base/content/lambda.rb
Overview
lambda represents a lambda expression for creating anonymous functions.
lambda represents a lambda expression for creating anonymous functions.